@@ -11,6 +11,6 @@ def lookup():
     if not word: word=Editor.selectionInSource()
     if not word: return
 
-    os.system("chromium-browser 'http://multitran.ru/c/m.exe?l1=1&l2=2&s=%s'" % word)
+    os.system("kfmclient newTab 'http://multitran.ru/c/m.exe?l1=1&l2=2&s=%s'" % word)
 
 lookup()
